@@ -22,7 +22,7 @@ from . import loaders
 from .admin_utils import action, display_field, fixedwidth
 from .models import (TaskState, WorkerState,
                      PeriodicTask, IntervalSchedule, CrontabSchedule)
-from .utils import naturaldate
+from .humanize import naturaldate
 
 
 TASK_STATE_COLORS = {states.SUCCESS: "green",
