@@ -32,8 +32,9 @@ def task_view(task):
 
     def _applier(request, **options):
         kwargs = kwdict(request.method == "POST" and \
-                        request.POST.copy() or request.GET.copy())
-        kwargs.update(options)
+                        request.POST or request.GET)
+        kwargs = dict((k, v[0])
+                        for k, v in dict(kwargs, **options).iteritems())
 
         result = task.apply_async(kwargs=kwargs)
         return JsonResponse({"ok": "true", "task_id": result.task_id})
